clearSyncState method

Future<void> clearSyncState()

Clears the sync state.

This should be called on logout to ensure the next sync after login is an initial sync rather than an incremental sync.

Implementation

Future<void> clearSyncState() {
  _ensureInitialized();
  return _database.clearSyncState();
}