currentUserId property
String?
get
currentUserId
The current user ID.
Returns null if the identity provider has no current user yet.
Implementation
String? get currentUserId => _userId;
The current user ID.
Returns null if the identity provider has no current user yet.
String? get currentUserId => _userId;