clearSyncState abstract method

Future<void> clearSyncState()

Clears the sync state (called on logout).

This ensures that after logout, the next sync will be an initial sync rather than an incremental sync.

Implementation

Future<void> clearSyncState();