ChatEventBusImpl class
Implementation of ChatEventBus using StreamController.
- Implemented types
Constructors
Properties
-
eventStream
→ Stream<
ChatEvent> -
Subscribes to chat events.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Disposes the event bus.
override
-
emit(
ChatEvent event) → void -
Publishes an event to all subscribers.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
T extends ChatEvent> () → Stream< T> -
Subscribes to a specific event type.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited