ChatIdentityProvider class abstract

Provides the current chat identity to the Chat SDK.

Implementers

Constructors

ChatIdentityProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIdChanges Stream<String?>
Emits whenever the current user id changes.
no setter

Methods

getCurrentUserId() Future<String?>
Returns the current user id, or null when the app is unauthenticated.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited