databaseEncryptionConfig property

DatabaseEncryptionConfig? databaseEncryptionConfig
final

Optional database encryption configuration.

When provided, the database will be encrypted using SQLCipher. The encryption key must be generated and managed at the app level.

See docs/chat-database-encryption.md for implementation guide.

Implementation

final DatabaseEncryptionConfig? databaseEncryptionConfig;