ChatSessionState enum
Current user-scoped readiness of the chat SDK.
Values
- initialized → const ChatSessionState
-
Local SDK services are initialized, but no current user is known yet.
- identified → const ChatSessionState
-
Current user is known; offline user-scoped data can be presented.
- connected → const ChatSessionState
-
Current user is known and the realtime connection is connected.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChatSessionState> - A constant List of the values in this enum, in order of their declaration.