ChatValidationException class

Exception thrown when validation fails.

Inheritance

Constructors

ChatValidationException(String message)
Creates a validation exception.
const

Properties

cause Object?
Underlying cause.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited