ConnectionEvent class

Event for connection state change.

Inheritance

Constructors

ConnectionEvent({required String eventId, required DateTime timestamp, required bool isConnected, String? error})
Creates a connection event.
const

Properties

error String?
Error if disconnected due to error.
final
eventId String
Unique event ID.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
Whether connected.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp DateTime
When the event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited