ConversationFilter class

Filter for querying conversations.

Constructors

ConversationFilter({ConversationMode? mode, ConversationStatus? status, ConversationType? type, String? searchQuery})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mode ConversationMode?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery String?
final
status ConversationStatus?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type ConversationType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited