CreateConversationParams class
Parameters for creating a conversation.
Constructors
-
CreateConversationParams({required ConversationType type, required ConversationMode mode, String? name, List<
String> ? participantIds, Duration? expiresIn, Map<String, dynamic> ? extra}) -
const
Properties
- expiresIn → Duration?
-
final
-
extra
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → ConversationMode
-
final
- name → String?
-
final
-
participantIds
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ConversationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited