DefaultAttachmentTypeStrategy class

Default extension sets used by MediaTypeResolver.

Inheritance

Constructors

DefaultAttachmentTypeStrategy()
const

Properties

audioExtensions List<String>
Extensions that are treated as audio (without leading dot, lowercase).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
imageExtensions List<String>
Extensions that are treated as images (without leading dot, lowercase).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoExtensions List<String>
Extensions that are treated as video (without leading dot, lowercase).
no setteroverride

Methods

mimeTypeOverride(String extension) String?
Return a non-null MIME type to override the default lookup for extension. extension is already normalized (no dot, lowercase).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited