EncryptionService class abstract

Encryption service for chat messages.

Provides encryption and decryption capabilities for message content. Implementations can use no-op encryption, AES, Sodium, or custom algorithms.

Constructors

EncryptionService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(List<int> encryptedData) Future<List<int>>
Decrypts the given encryptedData.
decryptString(String encryptedText) Future<String>
Decrypts a string.
dispose() Future<void>
Disposes the encryption service.
encrypt(List<int> data) Future<List<int>>
Encrypts the given data.
encryptString(String text) Future<String>
Encrypts a string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited