FileUploadStatus enum
Status of file upload.
Values
- pending → const FileUploadStatus
-
Not yet started.
- uploading → const FileUploadStatus
-
Currently uploading.
- completed → const FileUploadStatus
-
Upload completed.
- failed → const FileUploadStatus
-
Upload failed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FileUploadStatus> - A constant List of the values in this enum, in order of their declaration.