MessageContent class

Content of a message, supporting both plain and encrypted forms.

Constructors

MessageContent({String? plainText, String? cipherText, String? nonce})
Creates message content.
const
MessageContent.encrypted({required String cipherText, required String nonce})
Creates encrypted content where plainText is not yet available.
const
MessageContent.plain(String text)
Creates plain text content.
const

Properties

cipherText String?
Encrypted content (ciphertext).
final
displayText String
Display text (plain or placeholder if encrypted).
no setter
hashCode int
The hash code for this object.
no setterinherited
isEncrypted bool
Whether content is encrypted.
no setter
nonce String?
Encryption nonce.
final
plainText String?
Decrypted/plain text content.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? plainText, String? cipherText, String? nonce}) MessageContent
Creates a copy with updated fields.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited