MessageStatus enum

Message delivery status.

Tracks the lifecycle of a message from creation to being read.

Inheritance
Available extensions

Values

draft → const MessageStatus

Message created locally, not yet queued.

pending → const MessageStatus

Message is in outbound queue, waiting to be sent.

sending → const MessageStatus

Message is being sent to server.

sent → const MessageStatus

Server acknowledged receipt of the message.

delivered → const MessageStatus

Message delivered to recipient's device.

read → const MessageStatus

Message has been read by recipient.

failed → const MessageStatus

Message failed to send (will be retried).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MessageStatus>
A constant List of the values in this enum, in order of their declaration.