OutboundOperationType enum

Pending operations in the outbound queue.

Inheritance
Available extensions

Values

sendMessage → const OutboundOperationType
createRoom → const OutboundOperationType
deleteRoom → const OutboundOperationType
starMessage → const OutboundOperationType
unstarMessage → const OutboundOperationType
pinMessage → const OutboundOperationType
unpinMessage → const OutboundOperationType
addReaction → const OutboundOperationType
removeReaction → const OutboundOperationType
markRead → const OutboundOperationType
archiveRoom → const OutboundOperationType
unarchiveRoom → const OutboundOperationType
addParticipants → const OutboundOperationType
removeParticipant → const OutboundOperationType
updateParticipantStatus → const OutboundOperationType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OutboundOperationType>
A constant List of the values in this enum, in order of their declaration.