OutboundQueue class abstract

Interface for outbound queue operations.

Manages operations to be sent to the server. Operations are queued and retried automatically.

Implementers

Constructors

OutboundQueue()

Properties

hashCode int
The hash code for this object.
no setterinherited
pendingCount Stream<int>
Stream of pending operations count.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes the queue.
enqueue(OutboundOperation operation) Future<void>
Enqueues an operation.
initialize() Future<void>
Initializes the queue, loading any persisted operations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processQueue() Future<void>
Processes the queue.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited