OutboundQueueDatabase class abstract

Interface for database operations needed by the queue.

Implementers

Constructors

OutboundQueueDatabase()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteCompletedOperations() Future<void>
Deletes all completed operations.
deleteOperation(String operationId) Future<void>
Deletes an outbound operation.
getPendingOperations() Future<List<OutboundOperation>>
Gets all pending outbound operations.
insertOperation(OutboundOperation operation) Future<void>
Inserts an outbound operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateOperation(OutboundOperation operation) Future<void>
Updates an outbound operation.

Operators

operator ==(Object other) bool
The equality operator.
inherited