OutboundQueueImpl class

Implementation of OutboundQueue with database persistence.

Implemented types

Constructors

OutboundQueueImpl({required ChatAdapter adapter, required ChatDatabase database, QueueRetryConfig retryConfig = const QueueRetryConfig(), int maxQueueSize = kDefaultMaxQueueSize})
Creates an outbound queue.

Properties

hashCode int
The hash code for this object.
no setterinherited
pendingCount Stream<int>
Stream of pending operations count.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes the queue.
override
enqueue(OutboundOperation operation) Future<void>
Enqueues an operation.
override
initialize() Future<void>
Initializes the queue, loading any persisted operations.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processQueue() Future<void>
Processes the queue.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited