PresenceResult class
Result of a presence query for a specific user.
Constructors
- PresenceResult({required String userId, required bool active, DateTime? lastSeen})
-
Creates a presence result.
const
Properties
- active → bool
-
Whether the user is currently online.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastSeen → DateTime?
-
Last time the user was seen online (null if currently active).
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - userId → String
-
The queried user's ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited