QueueRetryConfig class

Configuration for queue retry behavior.

Constructors

QueueRetryConfig({int maxRetries = 3, int initialDelayMs = 1000, int maxDelayMs = 30000, double backoffMultiplier = 2.0})
Creates retry configuration.
const

Properties

backoffMultiplier double
Multiplier for exponential backoff.
final
hashCode int
The hash code for this object.
no setterinherited
initialDelayMs int
Initial delay in milliseconds before first retry.
final
maxDelayMs int
Maximum delay in milliseconds between retries.
final
maxRetries int
Maximum number of retry attempts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDelayForRetry(int retryCount) Duration
Calculates delay for given retry count.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited