ReactionEvent class

Event for reaction on message.

Inheritance

Constructors

ReactionEvent({required String eventId, required DateTime timestamp, required String conversationId, required String messageId, required Reaction reaction, bool isRemoved = false})
Creates a reaction event.
const

Properties

conversationId String
Conversation ID.
final
eventId String
Unique event ID.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isRemoved bool
Whether reaction was removed.
final
messageId String
Message ID.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
reaction Reaction
The reaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp DateTime
When the event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited