ReceiptEvent class
Event for message receipt (delivered/read).
Constructors
- ReceiptEvent({required String eventId, required DateTime timestamp, required String conversationId, required String messageId, required String userId, required ReceiptType type})
-
Creates a receipt event.
const
Properties
- conversationId → String
-
Conversation ID.
final
- eventId → String
-
Unique event ID.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
Message ID.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
When the event occurred.
finalinherited
- type → ReceiptType
-
Type of receipt.
final
- userId → String
-
User who received/read.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited