SendMessageParams class
Parameters for sending a message.
Constructors
-
SendMessageParams({required String conversationId, required String content, MessageType type = MessageType.text, String? replyToId, List<
PendingAttachment> ? attachments, String? nonce, Map<String, dynamic> ? extra}) -
const
Properties
-
attachments
→ List<
PendingAttachment> ? -
final
- content → String
-
final
- conversationId → String
-
final
-
extra
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonce → String?
-
final
- replyToId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → MessageType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited