SyncEngineImpl class

Implementation of SyncEngine.

Implemented types

Constructors

SyncEngineImpl({required ChatAdapter adapter, required ChatDatabase database, required ChatEventBus eventBus})
Creates a sync engine.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncStatus Stream<SyncStatus>
Stream of sync status.
no setteroverride

Methods

dispose() Future<void>
Disposes sync engine.
override
handleEvent(ChatEvent event, {String? currentUserId}) → void
Handles incoming event from adapter.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync() Future<void>
Performs full sync.
override
syncConversation(String conversationId) Future<SyncResult?>
Syncs a specific conversation. Returns the SyncResult if successful.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited