SyncResult class
Result of a sync operation.
Constructors
-
SyncResult({List<
Conversation> conversations = const [], List<Message> messages = const [], List<ChatEvent> events = const [], String? nextSyncToken, bool hasMore = false}) -
const
- SyncResult.empty()
-
const
Properties
-
conversations
→ List<
Conversation> -
final
-
events
→ List<
ChatEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
final
-
messages
→ List<
Message> -
final
- nextSyncToken → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited