AttachmentTypeStrategy class abstract
Strategy for customizing which file extensions are treated as each media type and for overriding MIME type lookups.
Extend DefaultAttachmentTypeStrategy for small customizations, or implement this interface to replace the defaults entirely.
- Implementers
Constructors
- AttachmentTypeStrategy()
-
const
Properties
-
audioExtensions
→ List<
String> -
Extensions that are treated as audio (without leading dot, lowercase).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageExtensions
→ List<
String> -
Extensions that are treated as images (without leading dot, lowercase).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
videoExtensions
→ List<
String> -
Extensions that are treated as video (without leading dot, lowercase).
no setter
Methods
-
mimeTypeOverride(
String extension) → String? -
Return a non-null MIME type to override the default lookup for
extension.extensionis already normalized (no dot, lowercase). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited