ChatEventBus class abstract
Event bus for chat events.
Provides a publish-subscribe mechanism for chat events. Allows multiple listeners to react to chat events.
- Implementers
Constructors
Properties
-
eventStream
→ Stream<
ChatEvent> -
Subscribes to chat events.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Disposes the event bus.
-
emit(
ChatEvent event) → void - Publishes an event to all subscribers.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
T extends ChatEvent> () → Stream< T> - Subscribes to a specific event type.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited