ConversationUpdateEvent class
Event for conversation update.
Constructors
- ConversationUpdateEvent({required String eventId, required DateTime timestamp, required Conversation conversation, required ConversationUpdateType updateType, Participant? participant})
-
Creates a conversation update event.
const
Properties
- conversation → Conversation
-
The conversation.
final
- eventId → String
-
Unique event ID.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- participant → Participant?
-
Affected participant (for participant events).
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
When the event occurred.
finalinherited
- updateType → ConversationUpdateType
-
Type of update.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited