FileUploadProgress class
Progress of file upload.
Constructors
- FileUploadProgress({required String fileId, required double progress, required FileUploadStatus status, String? error, FileAttachment? attachment})
-
Creates file upload progress.
const
Properties
- attachment → FileAttachment?
-
Completed attachment (when status is completed).
final
- error → String?
-
Error message if failed.
final
- fileId → String
-
File identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress → double
-
Progress (0.0 to 1.0).
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FileUploadStatus
-
Current status.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited