LoadMessagesResult class
Result of loading paginated messages.
Constructors
-
LoadMessagesResult({List<
Message> messages = const [], String? prevBatch, bool hasMore = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether there are more messages to load.
final
-
messages
→ List<
Message> -
Loaded messages.
final
- prevBatch → String?
-
Cursor for loading the next (older) page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited