MessageType enum
Type of message content.
Values
- text → const MessageType
-
Plain text message.
- image → const MessageType
-
Image attachment.
- video → const MessageType
-
Video attachment.
- audio → const MessageType
-
Audio attachment.
- file → const MessageType
-
Generic file attachment.
- system → const MessageType
-
System notification message (room events).
- notification → const MessageType
-
Legacy system notification message (alias).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MessageType> - A constant List of the values in this enum, in order of their declaration.