PresenceEvent class
Event for user presence (online/offline).
Constructors
Properties
- conversationId → String?
-
Conversation ID (if conversation-specific presence).
final
- eventId → String
-
Unique event ID.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOnline → bool
-
Whether user is online.
final
- lastSeenAt → DateTime?
-
Last seen timestamp.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
When the event occurred.
finalinherited
- userId → String
-
User ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited