Reaction class
Emoji reaction on a message.
Constructors
Properties
- createdAt → DateTime?
-
When the reaction was added.
final
- emoji → String
-
Emoji character.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - userId → String
-
User who added the reaction.
final
- userName → String?
-
Name of user who reacted.
final
Methods
-
copyWith(
{String? id, String? emoji, String? userId, String? userName, DateTime? createdAt}) → Reaction - Creates a copy with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited