SocketChatAdapter class abstract
Base class for WebSocket-only adapters.
Provides UnimplementedError for non-real-time operations (sync, CRUD). Override the methods your backend supports.
- Implemented types
Constructors
Properties
-
connectionState
→ Stream<
ChatConnectionState> -
no setterinherited
-
eventStream
→ Stream<
ChatEvent> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Whether the adapter is currently connected.
no setterinherited
- name → String
-
Adapter name for logging.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addParticipants(
String conversationId, List< String> userIds) → Future<void> -
override
-
addReaction(
String messageId, String emoji) → Future< void> -
override
-
archiveConversation(
String conversationId) → Future< void> -
override
-
connect(
) → Future< void> -
inherited
-
createConversation(
CreateConversationParams params) → Future< Conversation> -
override
-
deleteConversation(
String conversationId) → Future< void> -
override
-
deleteMessage(
String conversationId, String messageId) → Future< void> -
override
-
disconnect(
) → Future< void> -
inherited
-
dispose(
) → Future< void> -
Dispose adapter resources.
inherited
-
getConversation(
String conversationId) → Future< Conversation?> -
override
-
getPendingRequests(
String conversationId) → Future< List< Participant> > -
override
-
getPinnedMessages(
String conversationId) → Future< List< Message> > -
override
-
getPresence(
String userId) → Future< PresenceResult> -
inherited
-
override
-
getStarredMessages(
) → Future< List< Message> > -
override
-
getStarredMessagesByConversation(
String conversationId) → Future< List< Message> > -
override
-
incrementalSync(
String sinceToken) → Future< SyncResult> -
override
-
initialize(
) → Future< void> -
Initialize the adapter (called once at startup).
inherited
-
initialSync(
) → Future< SyncResult> -
override
-
joinConversation(
JoinConversationParams params) → Future< Conversation> -
override
-
loadMessages(
String conversationId, {String? before, int? limit}) → Future< LoadMessagesResult> -
override
-
markAsRead(
String conversationId, String messageId) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pinMessage(
String conversationId, String messageId, Duration? duration) → Future< void> -
override
-
removeParticipant(
String conversationId, String userId) → Future< void> -
override
-
removeReaction(
String messageId, String reactionId) → Future< void> -
override
-
sendMessage(
SendMessageParams params) → Future< Message> -
override
-
sendTyping(
String conversationId, bool isTyping) → Future< void> -
inherited
-
starMessage(
String conversationId, String messageId) → Future< String> -
override
-
startHeartbeat(
String userId, Duration interval) → void -
Start presence heartbeat. Override in socket-based adapters.
inherited
-
stopHeartbeat(
) → void -
Stop presence heartbeat. Override in socket-based adapters.
inherited
-
subscribePresence(
String userId) → Future< void> -
inherited
-
syncConversation(
String conversationId) → Future< SyncResult> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unarchiveConversation(
String conversationId) → Future< void> -
override
-
unpinMessage(
String conversationId, String messageId) → Future< void> -
override
-
unstarMessage(
String messageId) → Future< void> -
override
-
unsubscribePresence(
String userId) → Future< void> -
inherited
-
updateConversation(
String conversationId, UpdateConversationParams params) → Future< Conversation> -
override
-
updateParticipantStatus(
String conversationId, String userId, ParticipantStatus status) → Future< void> -
override
-
uploadFile(
UploadFileParams params) → Stream< FileUploadProgress> -
override
-
validateConversationCode(
String code) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited