SyncEngine class abstract
Interface for sync engine operations.
Manages synchronization between local database and remote server.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
syncStatus
→ Stream<
SyncStatus> -
Stream of sync status.
no setter
Methods
-
dispose(
) → Future< void> - Disposes sync engine.
-
handleEvent(
ChatEvent event, {String? currentUserId}) → void - Handles incoming event from adapter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
) → Future< void> - Performs full sync.
-
syncConversation(
String conversationId) → Future< SyncResult?> - Syncs a specific conversation. Returns the SyncResult if successful.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited