SyncState class
State of synchronization.
Constructors
- SyncState({String? lastSyncToken, DateTime? lastSyncAt, bool isInitialSyncComplete = false})
-
Creates sync state.
const
- SyncState.initial()
-
Initial state before any sync.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialSyncComplete → bool
-
Whether initial sync has completed.
final
- lastSyncAt → DateTime?
-
When last sync occurred.
final
- lastSyncToken → String?
-
Token for incremental sync.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? lastSyncToken, DateTime? lastSyncAt, bool? isInitialSyncComplete}) → SyncState - Creates a copy with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited