TypingEvent class
Event for typing indicator.
Constructors
Properties
- conversationId → String
-
Conversation where typing occurs.
final
- eventId → String
-
Unique event ID.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTyping → bool
-
Whether user is typing.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timestamp → DateTime
-
When the event occurred.
finalinherited
- userId → String
-
User who is typing.
final
- userName → String?
-
Name of user typing.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited